@@ -1,6 +1,9 @@
 use git_cliff_core::commit::Commit;
 use git_cliff_core::config::Config;
-use git_cliff_core::error::Result;
+use git_cliff_core::error::{
+	Error,
+	Result,
+};
 use git_cliff_core::release::Release;
 use git_cliff_core::template::Template;
 use std::io::Write;
@@ -16,19 +19,27 @@ pub struct Changelog<'a> {
 impl<'a> Changelog<'a> {
 	/// Constructs a new instance.
 	pub fn new(releases: Vec<Release<'a>>, config: &'a Config) -> Result<Self> {
+		let mut template = config
+			.changelog
+			.body
+			.as_deref()
+			.unwrap_or_default()
+			.to_string();
+		if template.is_empty() {
+			return Err(Error::ChangelogError(String::from(
+				"changelog body cannot be empty",
+			)));
+		}
+		if config.changelog.trim.unwrap_or(true) {
+			template = template
+				.lines()
+				.map(|v| v.trim())
+				.collect::<Vec<&str>>()
+				.join("\n")
+		}
 		let mut changelog = Self {
 			releases,
-			template: Template::new({
-				let mut template = config.changelog.body.to_string();
-				if config.changelog.trim == Some(true) {
-					template = template
-						.lines()
-						.map(|v| v.trim())
-						.collect::<Vec<&str>>()
-						.join("\n")
-				}
-				template
-			})?,
+			template: Template::new(template)?,
 			config,
 		};
 		changelog.process_commits();
@@ -64,6 +75,7 @@ impl<'a> Changelog<'a> {
 	fn process_releases(&mut self) {
 		debug!("Processing the releases...");
 		let skip_regex = self.config.git.skip_tags.as_ref();
+		let mut skipped_tags = Vec::new();
 		self.releases = self
 			.releases
 			.clone()
@@ -80,6 +92,7 @@ impl<'a> Changelog<'a> {
 						.map(|r| {
 							let skip_tag = r.is_match(version);
 							if skip_tag {
+								skipped_tags.push(version.clone());
 								trace!("Skipping release: {}", version)
 							}
 							skip_tag
@@ -90,17 +103,22 @@ impl<'a> Changelog<'a> {
 				}
 			})
 			.collect();
-		if skip_regex.is_some() {
-			let mut releases = self.releases.clone();
-			for (i, release) in self.releases.iter_mut().enumerate() {
-				if release.previous.is_none() {
-					continue;
-				}
-				if let Some(previous_release) = releases.get_mut(i + 1) {
+		for skipped_tag in &skipped_tags {
+			if let Some(release_index) = self.releases.iter().position(|release| {
+				release
+					.previous
+					.as_ref()
+					.and_then(|release| release.version.as_ref()) ==
+					Some(skipped_tag)
+			}) {
+				if let Some(previous_release) =
+					self.releases.get_mut(release_index + 1)
+				{
 					previous_release.previous = None;
-					release.previous = Some(Box::new(previous_release.clone()));
-				} else {
-					release.previous = None;
+					self.releases[release_index].previous =
+						Some(Box::new(previous_release.clone()));
+				} else if release_index == self.releases.len() - 1 {
+					self.releases[release_index].previous = None;
 				}
 			}
 		}
@@ -153,7 +171,7 @@ mod test {
 		let config = Config {
 			changelog: ChangelogConfig {
 				header: Some(String::from("# Changelog")),
-				body:   String::from(
+				body:   Some(String::from(
 					r#"{% if version %}
 				## Release [{{ version }}] - {{ timestamp | date(format="%Y-%m-%d") }}
 				({{ commit_id }}){% else %}
@@ -163,12 +181,12 @@ mod test {
 				#### {{ group }}{% for commit in commits %}
 				- {{ commit.message }}{% endfor %}
 				{% endfor %}{% endfor %}"#,
-				),
+				)),
 				footer: Some(String::from("------------")),
 				trim:   Some(true),
 			},
 			git:       GitConfig {
-				conventional_commits:  true,
+				conventional_commits:  Some(true),
 				filter_unconventional: Some(false),
 				commit_parsers:        Some(vec![
 					CommitParser {
@@ -204,8 +222,9 @@ mod test {
 				tag_pattern:           None,
 				skip_tags:             Regex::new("v3.*").ok(),
 				ignore_tags:           None,
-				topo_order:            Some(false),
+				date_order:            Some(false),
 				sort_commits:          Some(String::from("oldest")),
+				link_parsers:          None,
 			},
 		};
 		let test_release = Release {
